"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.subscribeTaskEvent = subscribeTaskEvent;
exports.formatEnv = formatEnv;
exports.getLog = getLog;
exports.clearLog = clearLog;

function _react() {
  const data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

var _enums = require("../core/enums");

var _util = require("../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const LOG = {
  [_enums.TaskType.BUILD]: '',
  [_enums.TaskType.DEV]: '',
  [_enums.TaskType.LINT]: '',
  [_enums.TaskType.TEST]: ''
};

const createLogSender = send => {
  return function sender({
    taskType,
    log,
    eventType,
    detail
  }) {
    const logData = log ? (0, _util.formatLog)(log) : ''; // 发送日志

    send({
      type: eventType,
      payload: {
        taskType,
        data: logData,
        detail: detail || null
      }
    }); // 保存日志

    if (eventType !== 'org.umi.task.log') {
      return;
    }

    LOG[taskType] = `${LOG[taskType]}${logData}`;
  };
};

let init = false;

function subscribeTaskEvent(taskManger, send) {
  if (init) {
    return;
  }

  init = true;
  const sender = createLogSender(send);
  taskManger.getAllTasks().forEach(({
    type,
    task
  }) => {
    task.on(_enums.TaskEventType.STD_OUT_DATA, data => {
      sender({
        eventType: 'org.umi.task.log',
        taskType: type,
        log: data
      });
    });
    task.on(_enums.TaskEventType.STD_ERR_DATA, data => {
      sender({
        eventType: 'org.umi.task.log',
        taskType: type,
        log: data
      });
    });
    task.on(_enums.TaskEventType.STATE_EVENT, () => {
      sender({
        eventType: 'org.umi.task.state',
        taskType: type,
        detail: taskManger.getTaskDetail(_enums.TaskType[type])
      });
    });
  });
}

function formatEnv(env) {
  const res = {};
  Object.keys(env).forEach(key => {
    if (typeof env[key] === 'boolean') {
      res[key] = env[key] ? '1' : 'none';
    } else {
      res[key] = env[key];
    }
  });
  return res;
}

function getLog(taskType) {
  return LOG[taskType] || '';
}

function clearLog(taskType) {
  LOG[taskType] = '';
}